@@ -24,7 +24,6 @@ import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.TreeMap;
-import java.util.Arrays;
 
 import relex.algs.SentenceAlgorithmApplier;
 import relex.anaphora.Antecedents;
@@ -39,17 +38,13 @@ import relex.concurrent.RelexContext;
 // import relex.corpus.QuotesParensSentenceDetector;
 import relex.corpus.DocSplitter;
 import relex.corpus.DocSplitterFactory;
-import relex.entity.EntityMaintainer;
-import relex.entity.EntityTagger;
-import relex.entity.EntityTaggerFactory;
 import relex.feature.FeatureNode;
 import relex.feature.LinkView;
-import relex.frame.Frame;
 import relex.morphy.Morphy;
 import relex.morphy.MorphyFactory;
 import relex.output.NLGInputView;
+import relex.output.LogicView;
 import relex.output.OpenCogScheme;
-import relex.output.ParseView;
 import relex.output.PrologList;
 import relex.output.RawView;
 import relex.output.SimpleView;
@@ -78,11 +73,16 @@ public class RelationExtractor
 {
 	public static final int verbosity = 1;
 
-	public static final int DEFAULT_MAX_PARSES = 100;
+	public static final int DEFAULT_MAX_PARSES = 4;
 	public static final int DEFAULT_MAX_SENTENCE_LENGTH = 1024;
 	public static final int DEFAULT_MAX_PARSE_SECONDS = 30;
 	public static final int DEFAULT_MAX_PARSE_COST = 1000;
 
+	private boolean _is_inited;
+	private boolean _use_sock;
+	private String _lang;
+	private String _dict_path;
+
 	/** The LinkParserClient to be used - this class isn't thread safe! */
 	private RelexContext context;
 
@@ -114,30 +114,46 @@ public class RelationExtractor
 	/** Expand preposition markup to two dependencies. */
 	public boolean do_expand_preps;
 
-	/** Perform entity substitution before parsing */
-	public boolean do_pre_entity_tagging;
-
-	/** Perform entity tagging after parse */
-	public boolean do_post_entity_tagging;
-	public EntityTagger tagger;
-
 	/** Statistics */
 	private ParseStats stats;
 
 	/* ---------------------------------------------------------- */
 	/* Constructors, etc. */
 
+	private void set_defaults()
+	{
+		_is_inited = false;
+		_use_sock = false;
+		_lang = "en";
+		_dict_path = null;
+
+		do_anaphora_resolution = false;
+		do_tree_markup = false;
+
+		do_stanford = false;
+		do_penn_tagging = false;
+		do_expand_preps = false;
+	}
+
 	public RelationExtractor()
 	{
-		init(false);
+		set_defaults();
 	}
+
 	public RelationExtractor(boolean useSocket)
 	{
-		init(useSocket);
+		set_defaults();
+		_use_sock = useSocket;
 	}
-	private void init(boolean useSocket)
+
+	private void init()
 	{
-		parser = useSocket ? new RemoteLGParser() : new LocalLGParser();
+		if (_is_inited) return;
+		_is_inited = true;
+
+		parser = _use_sock ? new RemoteLGParser() : new LocalLGParser();
+		if (null != _lang) parser.setLanguage(_lang);
+		if (null != _dict_path) parser.setDictPath(_dict_path);
 		parser.getConfig().setStoreConstituentString(true);
 		parser.getConfig().setStoreSense(true);
 		Morphy morphy = MorphyFactory.getImplementation(MorphyFactory.DEFAULT_SINGLE_THREAD_IMPLEMENTATION);
@@ -149,31 +165,31 @@ public class RelationExtractor
 		setMaxParseSeconds(DEFAULT_MAX_PARSE_SECONDS);
 		setMaxCost(DEFAULT_MAX_PARSE_COST);
 
+		// Hobbs-algo stuff.
 		phraseMarkup = new PhraseMarkup();
 		antecedents = new Antecedents();
 		hobbs = new Hobbs(antecedents);
-		do_anaphora_resolution = false;
 
 		doco = new Document();
 
-		do_tree_markup = false;
-
-		do_stanford = false;
-		do_penn_tagging = false;
-		do_expand_preps = false;
-		do_pre_entity_tagging = false;
-		do_post_entity_tagging = false;
-		tagger = null;
-
 		stats = new ParseStats();
 		sumtime = new TreeMap<String,Long>();
-		cnttime = new TreeMap<String,Long>(); 
+		cnttime = new TreeMap<String,Long>();
 	}
 
 	public String getVersion()
 	{
+		if (!_is_inited) init();
 		return parser.getVersion() + "\t" + Version.getVersion();
 	}
+	public void setLanguage(String lang)
+	{
+		_lang = lang;
+	}
+	public void setDictPath(String dict_path)
+	{
+		_dict_path = dict_path;
+	}
 
 	/* ---------------------------------------------------------- */
 	/* Control parameters, etc. */
@@ -184,18 +200,25 @@ public class RelationExtractor
 	 */
 	public void setMaxParses(int maxParses)
 	{
+		if (!_is_inited) init();
 		parser.getConfig().setMaxLinkages(maxParses);
 	}
 
-	public void setMaxCost(int maxCost) {
+	public void setMaxCost(int maxCost)
+	{
+		if (!_is_inited) init();
 		parser.getConfig().setMaxCost(maxCost);
 	}
 
-	public void setAllowSkippedWords(boolean allow) {
+	public void setAllowSkippedWords(boolean allow)
+	{
+		if (!_is_inited) init();
 		parser.getConfig().setAllowSkippedWords(allow);
 	}
 
-	public void setMaxParseSeconds(int maxParseSeconds) {
+	public void setMaxParseSeconds(int maxParseSeconds)
+	{
+		if (!_is_inited) init();
 		parser.getConfig().setMaxParseSeconds(maxParseSeconds);
 	}
 
@@ -211,59 +234,35 @@ public class RelationExtractor
 	 */
 	public void clear()
 	{
+		if (!_is_inited) init();
 		antecedents.clear();
 		hobbs = new Hobbs(antecedents);
 	}
 
 	public Sentence processSentence(String sentence)
 	{
-		return processSentence(sentence, null);
-	}
-
-	public Sentence processSentence(String sentence,
-	                                 EntityMaintainer entityMaintainer)
-	{
+		if (!_is_inited) init();
 		starttime = System.currentTimeMillis();
-		if (entityMaintainer == null)
-		{
-			entityMaintainer = new EntityMaintainer();
-		}
 
 		Sentence sntc = null;
 		try
 		{
 			if (verbosity > 0) starttime = System.currentTimeMillis();
-			sntc = parseSentence(sentence, entityMaintainer);
+			sntc = parseSentence(sentence);
 			if (verbosity > 0) reportTime("Link-parsing: ");
 
 			for (ParsedSentence parse : sntc.getParses())
 			{
-				if (do_expand_preps) 
+				if (do_expand_preps)
 				{
 					parse.getLeft().set("expand-preps", new FeatureNode("T"));
 				}
 
-				if (do_post_entity_tagging && (tagger != null))
-				{
-					// Markup feature node graph with entity info,
-					// so that the relex algs (next step) can see them.
-					tagger.tagEntities(sentence);
-					tagger.tagParse(parse);
-				}
-
-				// Markup feature node graph with entity info,
-				// so that the relex algs (next step) can see them.
-				entityMaintainer.tagConvertedSentence(parse);
-
 				// The actual relation extraction is done here.
 				sentenceAlgorithmApplier.applyAlgs(parse, context);
 				if (do_stanford) sentenceAlgorithmApplier.extractStanford(parse, context);
 				if (do_penn_tagging) sentenceAlgorithmApplier.pennTag(parse, context);
 
-				// Strip out the entity markup, so that when the
-				// sentence is printed, we don't print gunk.
-				entityMaintainer.repairSentence(parse.getLeft());
-
 				// Also do a Penn tree-bank style phrase structure markup.
 				if (do_tree_markup)
 				{
@@ -297,36 +296,29 @@ public class RelationExtractor
 
 	/**
 	 * Parses a sentence, using the parser. The private ArrayList of
-	 * currentParses is filled with the ParsedSentences Uses an optional
-	 * EntityMaintainer to work on a converted sentence.
+	 * currentParses is filled with the ParsedSentences.
 	 */
 	private Sentence
-	parseSentence(String sentence, EntityMaintainer entityMaintainer)
+	parseSentence(String sentence)
 	{
-		if (entityMaintainer != null)
-		{
-			entityMaintainer.convertSentence(sentence,null);
-			sentence = entityMaintainer.getConvertedSentence();
-		}
 		if (sentence == null) return null;
 
-		String orig_sentence = entityMaintainer.getOriginalSentence();
 		Sentence sent = null;
 		if (sentence.length() < DEFAULT_MAX_SENTENCE_LENGTH) {
 			sent = parser.parse(sentence);
 		} else {
-			System.err.println("Sentence too long!: " + sentence);
+			System.err.println("Sentence too long, len=" + sentence.length()
+				+ " : " + sentence);
 			sent = new Sentence();
 		}
-		sent.setSentence(orig_sentence);
 		return sent;
 	}
 
 	/* ---------------------------------------------------------- */
 	// Provide some basic timing info
 	Long starttime;
-	TreeMap<String,Long> sumtime; 
-	TreeMap<String,Long> cnttime; 
+	TreeMap<String,Long> sumtime;
+	TreeMap<String,Long> cnttime;
 
 	private void reportTime(String msg)
 	{
@@ -347,7 +339,7 @@ public class RelationExtractor
 		cnttime.put(msg, cnt);
 
 		Long avg = sum / cnt;
-		System.err.println(msg + elapsed + " milliseconds (avg=" 
+		System.err.println(msg + elapsed + " milliseconds (avg="
 			+ avg + " millisecs, cnt=" + cnt + ")");
 	}
 
@@ -390,18 +382,15 @@ public class RelationExtractor
 	{
 		String callString = "RelationExtractor" +
 			" [-a (perform anaphora resolution)]" +
-			" [-c (show plain output)]" +
 			" [--expand-preps (show expanded prepositions)]" +
-			" [-f (show frame output)]" +
-			" [-g (pre-process with GATE entity detector)]" +
-			" [--g-post (post-process with GATE entity detector)]" +
 			" [-h (show this help)]" +
 			" [-i (show output for generation)]" +
-			" [-l (show parse links)]" +
+			" [-l (show Link Grammar parse diagram)]" +
 			" [-m (show parse metadata)]" +
 			" [--maxParseSeconds N]" +
 			" [-n max number of parses to display]" +
 			" [-o (show opencog scheme output)]" +
+			" [--or (show opencog rule-based scheme output)]" +
 			" [--pa (show phrase-based lexical chunks)]" +
 			" [--pb (show pattern-based lexical chunks)]" +
 			" [--pc (show relational lexical chunks)]" +
@@ -413,21 +402,17 @@ public class RelationExtractor
 			" [--stanford (generate stanford-compatible output)]" +
 			" [-t (show parse tree)]" +
 			" [-v (verbose, full graph output)]" +
-			" [-x (show cerego XML output)]" +
 			" [--html filename (output HTML to file)]"
 				;
 		HashSet<String> flags = new HashSet<String>();
 		flags.add("-a");
-		flags.add("-c");
 		flags.add("--expand-preps");
-		flags.add("-f");
-		flags.add("-g");
-		flags.add("--g-post");
 		flags.add("-h");
 		flags.add("-i");
 		flags.add("-l");
 		flags.add("-m");
 		flags.add("-o");
+		flags.add("--or");
 		flags.add("--pa");
 		flags.add("--pb");
 		flags.add("--pc");
@@ -438,7 +423,6 @@ public class RelationExtractor
 		flags.add("--stanford");
 		flags.add("-t");
 		flags.add("-v");
-		flags.add("-x");
 		HashSet<String> opts = new HashSet<String>();
 		opts.add("-n");
 		opts.add("-s");
@@ -486,7 +470,7 @@ public class RelationExtractor
 
 		if (html != null) html.println("<html>");
 
-		RelationExtractor re = new RelationExtractor(false);
+		RelationExtractor re = new RelationExtractor();
 		re.setAllowSkippedWords(true);
 		re.setMaxParses(maxParses);
 		re.setMaxParseSeconds(maxParseSeconds);
@@ -524,19 +508,6 @@ public class RelationExtractor
 			re.do_expand_preps = true;
 		}
 
-		EntityTagger gent = null;
-		if ((commandMap.get("-g") != null) ||
-		    (commandMap.get("--g-post") != null))
-		{
-			re.starttime = System.currentTimeMillis();
-			gent = EntityTaggerFactory.get();
-			gent.tagEntities(""); // force initialization to measure initialization time
-			re.tagger = gent;
-			re.reportTime("Entity Detector Initialization: ");
-		}
-		if (commandMap.get("-g") != null) re.do_pre_entity_tagging = true;
-		if (commandMap.get("--g-post") != null) re.do_post_entity_tagging = true;
-
 		// If sentence is not passed at command line, read from standard input:
 		BufferedReader stdin = new BufferedReader(new InputStreamReader(System.in));
 		DocSplitter ds = DocSplitterFactory.create();
@@ -544,7 +515,6 @@ public class RelationExtractor
 		// QuotesParens is currently broken, it fails to handle possesives.
 		// QuotesParensSentenceDetector ds = QuotesParensSentenceDetector.create();
 
-		ParseView ceregoView = new ParseView();
 		OpenCogScheme opencog = null;
 		if (commandMap.get("-o") != null)
 		{
@@ -558,24 +528,12 @@ public class RelationExtractor
 			{
 				opencog.setShowRelex(false);
 			}
-			if (commandMap.get("-f") != null)
-			{
-				opencog.setShowFrames(true);
-			}
 			if (commandMap.get("-a") != null)
 			{
 				opencog.setShowAnaphora(true);
 			}
 		}
 
-		// Print normal frames, but only if -o has not been invoked.
-		Frame frame = null;
-		if ((commandMap.get("-f") != null) &&
-		    (commandMap.get("-o") == null))
-		{
-			frame = new Frame();
-		}
-
 		int sentence_count = 0;
 		boolean more_input = true;
 		while(more_input)
@@ -605,17 +563,7 @@ public class RelationExtractor
 			while (sentence != null)
 			{
 				System.out.println("; SENTENCE: ["+sentence+"]");
-				EntityMaintainer em = null;
-				if (re.do_pre_entity_tagging)
-				{
-					re.starttime = System.currentTimeMillis();
-					em = new EntityMaintainer();
-					gent.reset();
-					em.set(gent);
-					// gent.makeEntityTagger(sentence));
-					re.reportTime("Gate processing: ");
-				}
-				Sentence sntc = re.processSentence(sentence,em);
+				Sentence sntc = re.processSentence(sentence);
 				re.doco.addSentence(sntc);
 
 				if (html != null)
@@ -697,7 +645,7 @@ public class RelationExtractor
 					// Verbose graph.
 					if (commandMap.get("-v") != null)
 						// System.out.println("\n" + parse.fullParseString());
-						System.out.println("\n" + 
+						System.out.println("\n" +
 						 	parse.getLeft().toString(LinkView.getFilter()));
 
 					if ((commandMap.get("-q") == null) &&
@@ -712,6 +660,18 @@ public class RelationExtractor
 							html.printf("<td valign='top'><pre>%s</pre></td>\n", escape(SimpleView.printRelations(parse)));
 					}
 
+					if (commandMap.get("--or") != null)
+					{
+						LogicView logicView = new LogicView();
+
+						logicView.loadRules();
+
+						System.out.println("\n======\n");
+						System.out.println("Relex2Logic output:");
+						System.out.println(logicView.printRelationsNew(parse));
+						System.out.println("\n======\n");
+					}
+
 					if (commandMap.get("--pa") != null)
 					{
 						System.out.println("Phrase tree-based lexical chunks:");
@@ -741,7 +701,7 @@ public class RelationExtractor
 					{
 						PrologList pl = new PrologList();
 						System.out.println(
-							pl.toPrologList(parse.getLeft(), 
+							pl.toPrologList(parse.getLeft(),
 								PrologList.getDefaultFilter(),
 								true));
 						System.out.println("\n======\n");
@@ -749,51 +709,12 @@ public class RelationExtractor
 
 					if (commandMap.get("--stanford") != null)
 					{
+						System.out.println("Stanford-style dependency relations:\n");
 						System.out.println(
-							StanfordView.printRelations(parse, re.do_penn_tagging));
+							StanfordView.printRelations(parse, re.do_penn_tagging, "    "));
 						System.out.println("\n======\n");
 					}
 
-					if (commandMap.get("-c") != null)
-					{
-						ceregoView.setParse(parse);
-						ceregoView.showXML(false);
-						System.out.println(ceregoView.printCerego());
-						System.out.println("\n======\n");
-					}
-					if (commandMap.get("-x") != null)
-					{
-						System.out.print("-->\n");
-						ceregoView.setParse(parse);
-						ceregoView.showXML(true);
-						System.out.println(ceregoView.printCerego());
-						System.out.println("\n<!-- ======\n");
-					}
-					if ((commandMap.get("-f") != null) &&
-					    (commandMap.get("-o") == null))
-					{
-						re.starttime = System.currentTimeMillis();
-						String fin = SimpleView.printRelationsAlt(parse);
-						String[] fout = frame.process(fin);
-						re.reportTime("Frame processing: ");
-
-						Arrays.sort(fout);
-
-						for (int i=0; i < fout.length; i++) {
-							System.out.println(fout[i]);
-						}
-
-						if (html != null) {
-							html.print("<td valign='top'><pre>");
-							for (String f : fout) {
-								html.println(escape(f));
-							}
-							html.println("</pre></td>");
-						}
-
-						System.out.println("\nFraming rules applied:\n");
-						System.out.println(frame.printAppliedRules());
-					}
 					if (commandMap.get("-o") != null)
 					{
 						opencog.setParse(parse);
