@@ -25,14 +25,13 @@ import java.io.BufferedReader;
 import java.net.ServerSocket;
 import java.net.Socket;
 import relex.output.SimpleView;
-import relex.frame.Frame;
 import relex.output.OpenCogScheme;
-
+import relex.Version;
 
 /**
  * The Server class provides a very simple socket-based parse server.
  * It will listen for plain-text input sentences on port 4444, and will
- * generate OpenCog output.  
+ * generate OpenCog output.
  *
  * It is intended that this server be used by OpenCog agents to process
  * text; the text is sent from opencog to this server, and the returned
@@ -50,17 +49,19 @@ public class Server
 
 	public static void main(String[] args)
 	{
-		boolean frame_on = false;
+		int listen_port = 4444;
 		boolean relex_on = false;
 		boolean link_on = false;
 		boolean anaphora_on = false;
 		boolean verbose = false;
 		String usageString = "RelEx server (designed for OpenCog interaction).\n" +
+			"Given a sentence, it returns a parse in opencog-style scheme format.\n" +
+			" -p number  \t Port number to listen on (default: 4444)\n" +
+			" --port num \t Port number to listen on (default: 4444)\n" +
 			" --relex    \t Output RelEx relations (default)\n" +
 			" --link     \t Output Link Grammar Linkages\n" +
-			" --frame    \t Output Semantic Frames\n" +
 			" --anaphora \t Output anaphore references\n" +
-			" --verbose  \t Print parse/frame output to server stdout.\n";
+			" --verbose  \t Print parse output to server stdout.\n";
 
 		for (int i = 0; i < args.length; i++)
 		{
@@ -68,11 +69,7 @@ public class Server
 			{
 				anaphora_on = true;
 			}
-			else if (args[i].equals("--frame"))
-			{
-				frame_on = true;
-			}
-			else if (args[i].equals("--help") )
+			else if (args[i].equals("--help") || args[i].equals("-h"))
 			{
 				System.out.println(usageString);
 				System.exit(0);
@@ -81,6 +78,21 @@ public class Server
 			{
 				link_on = true;
 			}
+			else if (args[i].equals("--port") || args[i].equals("-p"))
+			{
+				i++;
+				if (i >= args.length) {
+					System.err.println("Error: Expected a port number after the -p flag.");
+					System.exit(1);
+				}
+
+				try {
+					listen_port = Integer.parseInt(args[i]);
+				} catch (NumberFormatException nfe) {
+					System.err.println("Error: Expected a port number after the -p flag.");
+					System.exit(1);
+				}
+			}
 			else if (args[i].equals("--relex"))
 			{
 				relex_on = true;
@@ -97,14 +109,18 @@ public class Server
 				System.exit(1);
 			}
 		}
+
+		System.err.println("Info: Version: " + Version.getVersion());
+
 		RelationExtractor r = new RelationExtractor(false);
 		OpenCogScheme opencog = new OpenCogScheme();
 		Server s = new Server();
+		s.listen_port = listen_port;
 		ServerSocket listen_sock = null;
 
-		if (!frame_on && !relex_on && !link_on)
+		if (!relex_on && !link_on)
 		{
-			// By default just export RelEx output, not frames
+			// By default just export RelEx output.
 			relex_on = true;
 		}
 		if (anaphora_on)
@@ -112,11 +128,6 @@ public class Server
 			System.err.println("Info: Anaphora output on.");
 			opencog.setShowAnaphora(anaphora_on);
 		}
-		if (frame_on)
-		{
-			System.err.println("Info: Frame output on.");
-			opencog.setShowFrames(frame_on);
-		}
 		if (link_on)
 		{
 			System.err.println("Info: Link grammar output on.");
@@ -170,22 +181,13 @@ public class Server
 				}
 				ParsedSentence parse = sntc.getParses().get(0);
 
-				// Print the phrase string .. why ?? 
+				// Print the phrase string .. why ??
 				out.println("; " + parse.getPhraseString());
 
 				if (verbose)
 				{
 					String fin = SimpleView.printRelationsAlt(parse);
 					System.out.print(fin);
-					if (frame_on)
-					{
-						Frame frame = new Frame();
-						String[] fout = frame.process(fin);
-						for (int i=0; i < fout.length; i++)
-						{
-							System.out.println(fout[i]);
-						}
-					}
 				}
 				opencog.setParse(parse);
 				out.println(opencog.toString());
@@ -194,7 +196,7 @@ public class Server
 				// just recieved a brand new sentence. The OpenCog scheme
 				// code depends on this being visible, in order to find
 				// the new sentence.
-				out.println("(ListLink (stv 1 1)");				
+				out.println("(ListLink (stv 1 1)");
 				out.println("   (AnchorNode \"# New Parsed Sentence\")");
 				out.println("   (SentenceNode \"" + sntc.getID() + "\")");
 				out.println(")");
