@@ -22,76 +22,61 @@ import java.util.concurrent.Callable;
 import relex.ParsedSentence;
 import relex.Sentence;
 import relex.algs.SentenceAlgorithmApplier;
-import relex.entity.EntityMaintainer;
 import relex.tree.PhraseMarkup;
 import relex.tree.PhraseTree;
 
 /**
  * Processes a sentence using the given LinkParserClient. When processing is
- * finished, returns the LPC to the pool. 
- *  
+ * finished, returns the LPC to the pool.
+ *
  * @author muriloq
  */
 public class RelexTask implements Callable<RelexTaskResult>
 {
 	public static final int DEBUG = 0;
-	// arguments 
+	// arguments
 	private int index;
 	private String sentence;
-	private EntityMaintainer entityMaintainer;
-	
-	// Reusable, shared processors 
+
+	// Reusable, shared processors
 	private SentenceAlgorithmApplier sentenceAlgorithmApplier;
 	private PhraseMarkup phraseMarkup;
 
 	// Used in mutual exclusion, must be returned to the pool
-	private RelexContext context; 
+	private RelexContext context;
 	private BlockingQueue<RelexContext> pool;
-	
+
 	public RelexTask(int index, String sentence,
-			EntityMaintainer entityMaintainer, 
 			SentenceAlgorithmApplier sentenceAlgorithmApplier,
 			PhraseMarkup phraseMarkup,
 			RelexContext context, BlockingQueue<RelexContext> pool){
 		this.index = index;
-		this.entityMaintainer = entityMaintainer; 
 		this.sentenceAlgorithmApplier = sentenceAlgorithmApplier;
 		this.phraseMarkup = phraseMarkup;
 		this.context = context;
 		this.pool = pool;
 		this.sentence = sentence;
 	}
-	
+
 	public RelexTaskResult call() {
 		try {
 			if (DEBUG > 0) System.err.println("[" + index + "] Start processing "+ sentence);
-			entityMaintainer.convertSentence(sentence,null);
-			String convertedSentence = entityMaintainer.getConvertedSentence().replace('\n', ' ').replace('\r', ' ');
-			if (DEBUG > 0) System.err.println("[" + index + "] End entity detection");
 			Sentence sntc = null;
 			try {
-				sntc = context.getParser().parse(convertedSentence);//, context.getLinkParserClient());
+				sntc = context.getParser().parse(sentence);//, context.getLinkParserClient());
 			} catch (RuntimeException ex) {
 				sntc = new Sentence();
 				sntc.setSentence(sentence);
 			}
-			
+
 			if (DEBUG > 0) System.err.println("[" + index + "] End parsing");
 
 			int i = 0;
 			for (ParsedSentence parse : sntc.getParses()) {
 				try {
-					// Markup feature node graph with entity info,
-					// so that the relex algs (next step) can see them.
-					entityMaintainer.tagConvertedSentence(parse);
-
 					// The actual relation extraction is done here.
 					sentenceAlgorithmApplier.applyAlgs(parse, context);
 
-					// Strip out the entity markup, so that when the
-					// sentence is printed, we don't print gunk.
-					entityMaintainer.repairSentence(parse.getLeft());
-
 					// Also do a Penn tree-bank style phrase structure markup.
 					if (phraseMarkup != null)
 					{
@@ -103,11 +88,11 @@ public class RelexTask implements Callable<RelexTaskResult>
 				} catch (Exception e) {
 					e.printStackTrace();
 				}
-				if (DEBUG > 0) 
-					System.err.println("[" + index+ "] end post-processing sentence " + 
+				if (DEBUG > 0)
+					System.err.println("[" + index+ "] end post-processing sentence " +
 							(i++) + "/"+ sntc.getParses().size());
 			}
-			return new RelexTaskResult(index, sentence, entityMaintainer, sntc);
+			return new RelexTaskResult(index, sentence, sntc);
 		} finally {
 			if (DEBUG > 0)
 				System.err.println("[" + index + "] End processing");
@@ -119,7 +104,7 @@ public class RelexTask implements Callable<RelexTaskResult>
 			if (DEBUG > 0) System.err.println("[" + index + "] Release resources");
 		}
 	}
-	
+
 	public String toString()
 	{
 		return index + ": " + sentence;
