@@ -42,11 +42,9 @@ public class OpenCogScheme
 
 	private OpenCogSchemeLink link_scheme;
 	private OpenCogSchemeRel rel_scheme;
-	private OpenCogSchemeFrame frame_scheme;
 	private OpenCogSchemeAnaphora anaphora_scheme;
 	private boolean do_show_linkage = false;
 	private boolean do_show_relex = false;
-	private boolean do_show_frames = false;
 	private boolean do_show_anaphora = false;
 
 	/* -------------------------------------------------------------------- */
@@ -55,7 +53,6 @@ public class OpenCogScheme
 	{
 		rel_scheme = new OpenCogSchemeRel();
 		link_scheme = new OpenCogSchemeLink();
-		frame_scheme = new OpenCogSchemeFrame();
 		anaphora_scheme = new OpenCogSchemeAnaphora();
 		orig_sentence = "";
 	}
@@ -66,9 +63,6 @@ public class OpenCogScheme
 	public void setShowRelex(boolean t) { do_show_relex = t; }
 	public boolean getShowRelex() { return do_show_relex; }
 
-	public void setShowFrames(boolean t) { do_show_frames = t; }
-	public boolean getShowFrames() { return do_show_frames; }
-
 	public void setShowAnaphora(boolean flag) { do_show_anaphora = flag; }
 	public boolean getShowAnaphora() { return do_show_anaphora; }
 
@@ -81,7 +75,6 @@ public class OpenCogScheme
 
 		link_scheme.setParse(parse);
 		rel_scheme.setParse(parse);
-		frame_scheme.setParse(parse);
 
 		anaphora_scheme.clear();
 		anaphora_scheme.setSentence(parse);
@@ -96,9 +89,8 @@ public class OpenCogScheme
 
 		if (do_show_linkage) ret += linkSchemeToString();
 		if (do_show_relex) ret += relSchemeToString();
-		if (do_show_frames) ret += frameSchemeToString();
-		if (do_show_anaphora) ret += anaphoraSchemeToString(); 
-		
+		if (do_show_anaphora) ret += anaphoraSchemeToString();
+
 		// Don't repeat the orig sentence, until we get a new sentence.
 		orig_sentence = "";
 		return ret;
@@ -108,10 +100,6 @@ public class OpenCogScheme
 		return anaphora_scheme.toString();
 	}
 
-	public String frameSchemeToString() {
-		return frame_scheme.toString();
-	}
-
 	public String relSchemeToString() {
 		return rel_scheme.toString();
 	}
@@ -189,7 +177,7 @@ public class OpenCogScheme
 		ArrayList<Sentence> sentence_list = doco.getSentences();
 		for (int i=0; i<sentence_list.size(); i++)
 		{
-			str += "      (SentenceNode \"" + 
+			str += "      (SentenceNode \"" +
 			       sentence_list.get(i).getID() + "\")\n";
 		}
 
@@ -206,5 +194,5 @@ public class OpenCogScheme
 	{
 		anaphora_scheme.setHistory(history);
 	}
-	
+
 } // end OpenCogScheme
