@@ -45,9 +45,17 @@ public class LocalLGParser extends LGParser
 
 	public void init()
 	{
+		// Must set language or dictionary path BEFORE initializing!
+		if (_lang != null)
+			LinkGrammar.setLanguage(_lang);
+
+		if (_dict_path != null)
+			LinkGrammar.setDictionariesPath(_dict_path);
+
 		if (!initialized.get())
 			LinkGrammar.init();
-		LGService.configure(config);
+
+		LGService.configure(_config);
 		initialized.set(Boolean.TRUE);
 	}
 
@@ -78,14 +86,14 @@ public class LocalLGParser extends LGParser
 		ArrayList<ParsedSentence> parses = new ArrayList<ParsedSentence>();
 
 		if ((numParses < 1) ||
-		    (!config.isAllowSkippedWords() && LinkGrammar.getNumSkippedWords() > 0))
+		    (!_config.isAllowSkippedWords() && LinkGrammar.getNumSkippedWords() > 0))
 		{
 			System.err.println("Warning: No parses found for:\n" +
 			     sentence);
 			return sntc;
 		}
 
-		for (int i = 0; i < numParses && i < config.getMaxLinkages(); i++)
+		for (int i = 0; i < numParses && i < _config.getMaxLinkages(); i++)
 		{
 			if (verbosity >= 5) System.err.println("making linkage for parse " + i);
 			LinkGrammar.makeLinkage(i);
@@ -111,13 +119,23 @@ public class LocalLGParser extends LGParser
 			 */
 			int startChar = 0;
 			HashMap<String,Integer> timesTokenSeen = new HashMap<String,Integer>();
-			// System.err.println("LINKPARSER NUMWORDS=" + numWords + "
-			// SKIPPED=" + cNumSkippedWords());
+
+			int skip_count = 0;
+			int[] skip_map = new int[numWords];
 			for (int w = 0; w < numWords; w++)
 			{
 				String wordString = LinkGrammar.getLinkageWord(w);
 				if (verbosity >= 5) System.err.println(" Processing Word " + wordString);
 
+				// In Russian, some words (suffixes) can be zero-length.
+				if (0 == wordString.length())
+				{
+					skip_count ++;
+					skip_map[w] = w-skip_count;
+					continue;
+				}
+				skip_map[w] = w-skip_count;
+
 				if (wordString.equals("RIGHT-WALL"))
 				{
 					ignoreLast = true;
@@ -173,7 +191,7 @@ public class LocalLGParser extends LGParser
 					timesTokenSeen.put(tokenString, new Integer(timesSeen + 1));
 					int endChar = (startChar >= 0 ? startChar + tokenString.length() : -1);
 					// System.err.println("INFO IS " + startChar + "," + endChar);
-					LinkableView.setCharIndices(fn, startChar, endChar, w);
+					LinkableView.setCharIndices(fn, startChar, endChar, w-skip_count);
 
 					// Increment index to start looking for next tokenString
 					// after the current one. Use "max" to prevent decreasing
@@ -199,8 +217,8 @@ public class LocalLGParser extends LGParser
 
 			// add linkage and tree structure
 			if (verbosity >= 5) System.err.println("Adding Linkage Structure");
-			addLinkageStructure(s, ignoreFirst, ignoreLast, config.isStoreSense());
-			if (config.isStoreConstituentString())
+			addLinkageStructure(s, ignoreFirst, ignoreLast, _config.isStoreSense(), skip_map);
+			if (_config.isStoreConstituentString())
 			{
 				if (verbosity >= 5) System.err.println("Adding Tree Structure");
 				s.setPhraseString(LinkGrammar.getConstituentString());
@@ -228,9 +246,15 @@ public class LocalLGParser extends LGParser
 	private void addLinkageStructure(ParsedSentence s,
 	                                 boolean ignoreFirst,
 	                                 boolean ignoreLast,
-	                                 boolean load_senses)
+	                                 boolean load_senses,
+	                                 int[] skip_map)
 	{
-		int length = LinkGrammar.getNumWords();
+		// Russian sentences can have 'blank words' in them which we skip.
+		// That means that the count of actual non-empty words no longer
+		// matches the link-parser count.  Technically, this is a link-parser
+		// bug, but fixing it would require a major re-write of the parser.
+		// int length = LinkGrammar.getNumWords();
+		int length = skip_map[skip_map.length-1] + 1;
 		int numLinks = LinkGrammar.getNumLinks();
 		s.setLinkString(LinkGrammar.getLinkString());
 		for (int i = 0; i < numLinks; i++)
@@ -238,6 +262,8 @@ public class LocalLGParser extends LGParser
 			boolean bad = false;
 			int left = LinkGrammar.getLinkLWord(i);
 			int right = LinkGrammar.getLinkRWord(i);
+			left = skip_map[left];
+			right = skip_map[right];
 			if (ignoreLast && (right == length - 1))
 			{
 				bad = true;
